@@ -269,7 +269,7 @@ class TestPost:
         status, *_ = conn.post("/post")
         assert status == 200
 
-    def test_post_no_payload(self, requests_mock):
+    def test_post_with_payload(self, requests_mock):
         requests_mock.post(
             "https://demo.dev/post", status_code=200,
             additional_matcher=lambda r: r.json()["post"] == "payload",
@@ -295,7 +295,7 @@ class TestPatch:
         status, *_ = conn.patch("/patch")
         assert status == 200
 
-    def test_patch_no_payload(self, requests_mock):
+    def test_patch_with_payload(self, requests_mock):
         requests_mock.patch(
             "https://demo.dev/patch", status_code=200,
             additional_matcher=lambda r: r.json()["patch"] == "payload",
@@ -314,6 +314,17 @@ class TestPatch:
         assert status == 200
 
 
+class TestPut:
+    def test_put_with_payload(self, requests_mock):
+        requests_mock.put(
+            "https://demo.dev/put", status_code=200,
+            additional_matcher=lambda r: r.json()["put"] == "payload",
+        )
+        conn = Connector("https://demo.dev", None, None)
+        status, *_ = conn.put("/put", dict(put="payload"))
+        assert status == 200
+
+
 class TestDelete:
     def test_delete(self, requests_mock):
         requests_mock.delete("https://demo.dev/delete", status_code=204)
